@@ -357,6 +357,15 @@ if hasattr(QWidget, "getContentsMargins"):
     __QWidget_getContentsMargins = QWidget.getContentsMargins
     QWidget.getContentsMargins = QWidget_getContentsMargins
 
+if hasattr(QLineEdit, "getTextMargins"):
+    def __QLineEdit_getTextMargins(self):
+        warn("QLineEdit.getTextMargins is deprecated and will be removed.",
+             DeprecationWarning, stacklevel=2)
+        m = self.textMargins()
+        return m.left(), m.top(), m.right(), m.bottom()
+    QLineEdit.getTextMargins = __QLineEdit_getTextMargins
+    del __QLineEdit_getTextMargins
+
 if hasattr(QApplication, "desktop"):
     def QApplication_desktop():
         warn("QApplication.desktop is obsolete and is removed in Qt6",
@@ -365,3 +374,74 @@ if hasattr(QApplication, "desktop"):
     __QApplication_desktop = QApplication.desktop
     QApplication.desktop = staticmethod(QApplication_desktop)
     del QApplication_desktop
+
+
+from AnyQt.QtCore import Signal, Slot
+
+if not hasattr(QButtonGroup, "idClicked"):
+    class QButtonGroup(QButtonGroup):
+        idClicked = Signal(int)
+        idPressed = Signal(int)
+        idReleased = Signal(int)
+        idToggled = Signal(int, bool)
+
+        def __init__(self, *args, **kwargs):
+            buttonClicked = kwargs.pop("buttonClicked", None)
+            buttonPressed = kwargs.pop("buttonPressed", None)
+            buttonReleased = kwargs.pop("buttonReleased", None)
+            buttonToggled = kwargs.pop("buttonToggled", None)
+            super().__init__(*args, **kwargs)
+            self.buttonClicked.connect(self.__button_clicked)
+            self.buttonPressed.connect(self.__button_pressed)
+            self.buttonReleased.connect(self.__button_released)
+            self.buttonToggled.connect(self.__button_toggled)
+            if buttonClicked is not None:
+                self.buttonClicked.connect(buttonClicked)
+            if buttonPressed is not None:
+                self.buttonPressed.connect(buttonPressed)
+            if buttonReleased is not None:
+                self.buttonReleased.connect(buttonReleased)
+            if buttonToggled is not None:
+                self.buttonToggled.connect(buttonToggled)
+
+        @Slot(QAbstractButton)
+        def __button_clicked(self, button):
+            self.idClicked.emit(self.id(button))
+
+        @Slot(QAbstractButton)
+        def __button_pressed(self, button):
+            self.idPressed.emit(self.id(button))
+
+        @Slot(QAbstractButton)
+        def __button_released(self, button):
+            self.idReleased.emit(self.id(button))
+
+        @Slot(QAbstractButton, bool)
+        def __button_toggled(self, button, checked):
+            self.idToggled.emit(self.id(button), checked)
+
+if not hasattr(QComboBox, "textActivated"):
+    class QComboBox(QComboBox):
+        textActivated = Signal(str)
+        textHighlighted = Signal(str)
+
+        def __init__(self, *args, **kwargs):
+            activated = kwargs.pop("activated", None)
+            highlighted = kwargs.pop("highlighted", None)
+            super().__init__(*args, **kwargs)
+            self.activated[int].connect(self.__activated)
+            self.highlighted[int].connect(self.__highlighted)
+            if activated is not None:
+                self.activated.connect(activated)
+            if highlighted is not None:
+                self.highlighted.connect(highlighted)
+
+        @Slot(int)
+        def __activated(self, index):
+            self.textActivated.emit(self.itemText(index))
+
+        @Slot(int)
+        def __highlighted(self, index):
+            self.textHighlighted.emit(self.itemText(index))
+
+del Signal, Slot
